@@ -42,7 +42,7 @@ class MetabaseClient:
             verify {Union[str, bool]} -- Path to certificate or disable verification. (default: {None})
         """
 
-        self.host = host
+        self.host = host.rstrip('/')
         self.verify = verify
         self.session_id = self.get_session_id(user, password)
         self.collections: Iterable = []
@@ -451,8 +451,9 @@ class MetabaseClient:
         if authenticated:
             headers["X-Metabase-Session"] = self.session_id
 
+        url_path = f"{self.host}{path}"
         response = requests.request(
-            method, f"{self.host}{path}", verify=self.verify, **kwargs
+            method, url_path, verify=self.verify, **kwargs
         )
 
         if critical:
@@ -471,7 +472,10 @@ class MetabaseClient:
         elif not response.ok:
             return {}
 
-        response_json = json.loads(response.text)
+        try:
+            response_json = json.loads(response.text)
+        except:
+            raise Exception("Unable to run API Request on ({}): {}".format(url_path, response.text or '(empty)'))
 
         # Since X.40.0 responses are encapsulated in "data" with pagination parameters
         if "data" in response_json:
